@@ -58,7 +58,7 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
     insight::formula_ok(model)
   }
 
-  # check for valid input
+
   metrics <- .check_bad_metrics(metrics, all_metrics, verbose)
   info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
 
@@ -72,30 +72,22 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
 
   # AIC -------------
   if ("AIC" %in% toupper(metrics)) {
-    out$AIC <- tryCatch(performance_aic(model, model_info = info),
-      error = function(e) NULL
-    )
+    out$AIC <- .safe(performance_aic(model, model_info = info))
   }
 
   # AICc -------------
   if ("AICC" %in% toupper(metrics)) {
-    out$AICc <- tryCatch(performance_aicc(model),
-      error = function(e) NULL
-    )
+    out$AICc <- .safe(performance_aicc(model))
   }
 
   # BIC -------------
   if ("BIC" %in% toupper(metrics)) {
-    out$BIC <- tryCatch(.get_BIC(model),
-      error = function(e) NULL
-    )
+    out$BIC <- .safe(.get_BIC(model))
   }
 
   # R2 -------------
   if (any(c("R2", "R2_ADJ") %in% toupper(metrics))) {
-    R2 <- tryCatch(r2(model, verbose = verbose, model_info = info),
-      error = function(e) NULL
-    )
+    R2 <- .safe(r2(model, verbose = verbose, model_info = info))
     if (!is.null(R2)) {
       attrib$r2 <- attributes(R2)
       if ("R2" %in% toupper(metrics) && "R2" %in% names(R2)) {
@@ -121,40 +113,29 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
 
   # RMSE -------------
   if ("RMSE" %in% toupper(metrics)) {
-    out$RMSE <- tryCatch(performance_rmse(model, verbose = verbose),
-      error = function(e) NULL
-    )
+    out$RMSE <- .safe(performance_rmse(model, verbose = verbose))
   }
 
   # SIGMA -------------
   if ("SIGMA" %in% toupper(metrics)) {
-    out$Sigma <- tryCatch(.get_sigma(model, verbose = verbose),
-      error = function(e) NULL
-    )
+    out$Sigma <- .safe(.get_sigma(model, verbose = verbose))
   }
 
   # LOGLOSS -------------
   if (("LOGLOSS" %in% toupper(metrics)) && isTRUE(info$is_binomial)) {
-    out$Log_loss <- tryCatch(
-      {
-        .logloss <- performance_logloss(model, verbose = verbose)
-        if (!is.na(.logloss)) {
-          .logloss
-        } else {
-          NULL
-        }
-      },
-      error = function(e) {
+    out$Log_loss <- .safe({
+      .logloss <- performance_logloss(model, verbose = verbose)
+      if (is.na(.logloss)) {
         NULL
+      } else {
+        .logloss
       }
-    )
+    })
   }
 
   # SCORE -------------
   if (("SCORE" %in% toupper(metrics)) && (isTRUE(info$is_binomial) || isTRUE(info$is_count))) {
-    .scoring_rules <- tryCatch(performance_score(model, verbose = verbose),
-      error = function(e) NULL
-    )
+    .scoring_rules <- .safe(performance_score(model, verbose = verbose))
     if (!is.null(.scoring_rules)) {
       if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
       if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
@@ -166,13 +147,11 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
     isTRUE(info$is_binomial) &&
     isFALSE(info$is_multinomial) &&
     isFALSE(info$is_ordinal)) {
-    out$PCP <- tryCatch(performance_pcp(model, verbose = verbose)$pcp_model,
-      error = function(e) NULL
-    )
+    out$PCP <- .safe(performance_pcp(model, verbose = verbose)$pcp_model)
   }
 
 
-  out <- as.data.frame(insight::compact_list(out, remove_na = TRUE))
+  out <- as.data.frame(insight::compact_list(out, remove_na = TRUE), check.names = FALSE)
 
   # check if model was actually supported...
   if (nrow(out) == 0 || ncol(out) == 0) {
@@ -254,6 +233,11 @@ model_performance.vglm <- model_performance.lm
 #' @export
 model_performance.fixest <- model_performance.lm
 
+#' @export
+model_performance.fixest_multi <- function(model, metrics = "all", verbose = TRUE, ...) {
+  lapply(model, model_performance.fixest)
+}
+
 #' @export
 model_performance.DirichletRegModel <- model_performance.lm
 
@@ -269,6 +253,22 @@ model_performance.zeroinfl <- model_performance.lm
 #' @export
 model_performance.zerotrunc <- model_performance.lm
 
+#' @export
+model_performance.nestedLogit <- function(model, metrics = "all", verbose = TRUE, ...) {
+  mp <- lapply(model$models, model_performance.lm, metrics = metrics, verbose = verbose, ...)
+  out <- cbind(
+    data.frame(Response = names(mp), stringsAsFactors = FALSE),
+    do.call(rbind, mp)
+  )
+  # need to handle R2 separately
+  if (any(c("ALL", "R2") %in% toupper(metrics))) {
+    out$R2 <- unlist(r2_tjur(model))
+  }
+
+  row.names(out) <- NULL
+  class(out) <- unique(c("performance_model", class(out)))
+  out
+}
 
 
 
