@@ -1,6 +1,5 @@
 #' @export
 model_performance.default <- function(model, metrics = "all", verbose = TRUE, ...) {
-  # check for valid input
   .is_model_valid(model)
 
   if (any(tolower(metrics) == "log_loss")) {
@@ -16,12 +15,12 @@ model_performance.default <- function(model, metrics = "all", verbose = TRUE, ..
     metrics <- c("AIC", "BIC", "R2", "R2_adj", "RMSE")
   }
 
-  # check for valid input
+
   metrics <- .check_bad_metrics(metrics, all_metrics, verbose)
 
   if (!insight::is_model(model) || !insight::is_model_supported(model)) {
     if (isTRUE(verbose)) {
-      warning(paste0("Objects of class '", class(model)[1], "' are not supported model objects."), call. = FALSE)
+      insight::format_warning(paste0("Objects of class `", class(model)[1], "` are not supported model objects."))
     }
     return(NULL)
   }
@@ -32,14 +31,13 @@ model_performance.default <- function(model, metrics = "all", verbose = TRUE, ..
 
 
 .check_bad_metrics <- function(metrics, all_metrics, verbose = TRUE) {
-  # check for valid input
   bad_metrics <- which(!metrics %in% all_metrics)
   if (length(bad_metrics)) {
     if (verbose) {
-      warning(paste0("Following elements are no valid metric: ",
-        metrics[bad_metrics],
-        collapse = ", "
-      ), call. = FALSE)
+      insight::format_warning(paste0(
+        "Following elements are no valid metric: ",
+        datawizard::text_concatenate(metrics[bad_metrics], enclose = "`")
+      ))
     }
     metrics <- metrics[-bad_metrics]
   }
